@@ -1761,6 +1761,8 @@ void R_init_refGenome(DllInfo *info)
 	};
 	//			{ "",	(DL_FUNC) &,	}
 	R_registerRoutines(info, NULL, cmd, NULL, NULL);
+	R_useDynamicSymbols(info, TRUE);
+	R_forceSymbols(info, TRUE);
 }
 
 
